# -*- coding: utf-8 -*-
"""
Created on Fri May 26 09:13:56 2023

@author: heyunan
"""

import pickle
import matplotlib.pyplot as plt
import os


weights_dir = './weights'

dir_names = [name for name in os.listdir(weights_dir) if os.path.isdir(os.path.join(weights_dir, name))]

for d in dir_names:
    d_path = os.path.join(weights_dir, d)
    pickle_path = os.path.join(d_path, 'results.pickle') 

    with open(pickle_path, 'rb') as f:
        data = pickle.load(f)

    iterations = [x[0] for x in data]
    
    b0_curves_x = [x[1][0] for x in data]
    b0_curves_y = [x[1][1] for x in data]
    
    b0_cx_data = [x[2] for x in data]
    b0_cy_data = [x[3] for x in data]
    
    b1_curves_x = [x[4][0] for x in data]
    b1_curves_y = [x[4][1] for x in data]
    
    b1_cx_data = [x[5] for x in data]
    b1_cy_data = [x[6] for x in data]

    # 绘制贝蒂-0曲线
    plt.figure(figsize=(10, 6))
    for i in range(len(b0_curves_y)):
        plt.plot(b0_curves_x[i], b0_curves_y[i], label=f'Iteration {iterations[i]}')
    plt.xlabel('Filtration parameter')
    plt.ylabel(r'Betti number ($\beta_{0}$)')
    plt.title('Betti-0 Curve')
    plt.legend()
    plt.savefig(f"{d_path}/b0_curve.pdf")
    plt.clf()

    # 绘制贝蒂-0曲线下方的面积的质心的x坐标随迭代次数的变化图
    plt.figure(figsize=(10, 6))
    plt.scatter(iterations, b0_cx_data, label=f'{d}')
    plt.xlabel('Iteration')
    plt.ylabel('Centroid x-coordinate of area under Betti-0 curve')
    plt.title('Centroid x-coordinate of area under Betti-0 curve vs. Iteration')
    plt.legend()
    plt.savefig(f"{d_path}/b0_centroid.pdf")
    plt.clf()

    # 绘制贝蒂-1曲线
    plt.figure(figsize=(10, 6))
    for i in range(len(b1_curves_y)):
        plt.plot(b1_curves_x[i], b1_curves_y[i], label=f'Iteration {iterations[i]}')
    plt.xlabel('Filtration parameter')
    plt.ylabel(r'Betti number ($\beta_{1}$)')
    plt.title('Betti-1 Curve')
    plt.legend()
    plt.savefig(f"{d_path}/b1_curve.pdf")
    plt.clf()

    # 绘制贝蒂-1曲线下方的面积的质心的x坐标随迭代次数的变化图
    plt.figure(figsize=(10, 6))
    plt.scatter(iterations, b1_cx_data, label=f'{d}')
    plt.xlabel('Iteration')
    plt.ylabel('Centroid x-coordinate of area under Betti-1 curve')
    plt.title('Centroid x-coordinate of area under Betti-1 curve vs. Iteration')
    plt.legend()
    plt.savefig(f"{d_path}/b1_centroid_x.pdf")
    plt.clf()

    # 绘制贝蒂-1曲线下方的面积的质心的y坐标随迭代次数的变化图
    plt.figure(figsize=(10, 6))
    plt.scatter(iterations, b1_cy_data, label=f'{d}')
    plt.xlabel('Iteration')
    plt.ylabel('Centroid y-coordinate of area under Betti-1 curve')
    plt.title('Centroid y-coordinate of area under Betti-1 curve vs. Iteration')
    plt.legend()
    plt.savefig(f"{d_path}/b1_centroid_y.pdf")
    plt.clf()